@@ -329,9 +329,9 @@ void
 writeheader(FILE *fp, const char *title)
 {
 	fputs("<!DOCTYPE html>\n"
-		"<html dir=\"ltr\" lang=\"en\">\n<head>\n"
+		"<html>\n<head>\n"
 		"<meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\" />\n"
-		"<meta http-equiv=\"Content-Language\" content=\"en\" />\n<title>", fp);
+		"<title>", fp);
 	xmlencode(fp, title, strlen(title));
 	if (title[0] && strippedname[0])
 		fputs(" - ", fp);
@@ -883,13 +883,10 @@ refs_cmp(const void *v1, const void *v2)
 {
 	git_reference *r1 = (*(git_reference **)v1);
 	git_reference *r2 = (*(git_reference **)v2);
-	int t1, t2;
+	int r;
 
-	t1 = git_reference_is_branch(r1);
-	t2 = git_reference_is_branch(r2);
-
-	if (t1 != t2)
-		return t1 - t2;
+	if ((r = git_reference_is_branch(r1) - git_reference_is_branch(r2)))
+		return r;
 
 	return strcmp(git_reference_shorthand(r1),
 	              git_reference_shorthand(r2));
@@ -1041,11 +1038,14 @@ main(int argc, char *argv[])
 	}
 
 	/* find HEAD */
-	if (git_revparse_single(&obj, repo, "HEAD"))
-		return 1;
-	head = git_object_id(obj);
+	if (!git_revparse_single(&obj, repo, "HEAD"))
+		head = git_object_id(obj);
 	git_object_free(obj);
 
+	/* don't cache if there is no HEAD */
+	if (!head)
+		cachefile = NULL;
+
 	/* use directory name as name */
 	if ((name = strrchr(repodirabs, '/')))
 		name++;
@@ -1085,12 +1085,17 @@ main(int argc, char *argv[])
 	}
 
 	/* check LICENSE */
-	haslicense = !git_revparse_single(&obj, repo, "HEAD:LICENSE");
+	haslicense = (!git_revparse_single(&obj, repo, "HEAD:LICENSE") &&
+		git_object_type(obj) == GIT_OBJ_BLOB);
 	git_object_free(obj);
+
 	/* check README */
-	hasreadme = !git_revparse_single(&obj, repo, "HEAD:README");
+	hasreadme = (!git_revparse_single(&obj, repo, "HEAD:README") &&
+		git_object_type(obj) == GIT_OBJ_BLOB);
 	git_object_free(obj);
-	hassubmodules = !git_revparse_single(&obj, repo, "HEAD:.gitmodules");
+
+	hassubmodules = (!git_revparse_single(&obj, repo, "HEAD:.gitmodules") &&
+		git_object_type(obj) == GIT_OBJ_BLOB);
 	git_object_free(obj);
 
 	/* log for HEAD */
@@ -1136,7 +1141,8 @@ main(int argc, char *argv[])
 		}
 		fclose(wcachefp);
 	} else {
-		writelog(fp, head);
+		if (head)
+			writelog(fp, head);
 	}
 
 	fputs("</tbody></table>", fp);
@@ -1146,7 +1152,8 @@ main(int argc, char *argv[])
 	/* files for HEAD */
 	fp = efopen("files.html", "w");
 	writeheader(fp, "Files");
-	writefiles(fp, head, "HEAD");
+	if (head)
+		writefiles(fp, head, "HEAD");
 	writefooter(fp);
 	fclose(fp);
 
